@@ -28,10 +28,6 @@
 #ifndef __COGL_DEFINES_H__
 #define __COGL_DEFINES_H__
 
-#include <glib.h>
-
-G_BEGIN_DECLS
-
 
 #define COGL_SYSDEF_POLLIN 1
 #define COGL_SYSDEF_POLLPRI 2
@@ -41,6 +37,7 @@ G_BEGIN_DECLS
 #define COGL_SYSDEF_POLLNVAL 32
 
 #define COGL_HAS_GLIB_SUPPORT 1
+#define COGL_HAS_GTYPE_SUPPORT 1
 #define COGL_HAS_GL 1
 #define CLUTTER_COGL_HAS_GL 1
 #define COGL_HAS_GLX_SUPPORT 1
@@ -50,10 +47,8 @@ G_BEGIN_DECLS
 #define COGL_HAS_XLIB_SUPPORT 1
 
 #define COGL_VERSION_MAJOR_INTERNAL 1
-#define COGL_VERSION_MINOR_INTERNAL 12
-#define COGL_VERSION_MICRO_INTERNAL 2
-#define COGL_VERSION_STRING_INTERNAL "1.12.2"
-
-G_END_DECLS
+#define COGL_VERSION_MINOR_INTERNAL 14
+#define COGL_VERSION_MICRO_INTERNAL 0
+#define COGL_VERSION_STRING_INTERNAL "1.14.0"
 
 #endif
