@@ -59,8 +59,8 @@ GType cogl_fog_mode_get_type (void) G_GNUC_CONST;
 GType cogl_blend_string_error_get_type (void) G_GNUC_CONST;
 #define COGL_TYPE_BLEND_STRING_ERROR (cogl_blend_string_error_get_type())
 
-GType cogl_error_get_type (void) G_GNUC_CONST;
-#define COGL_TYPE_ERROR (cogl_error_get_type())
+GType cogl_system_error_get_type (void) G_GNUC_CONST;
+#define COGL_TYPE_SYSTEM_ERROR (cogl_system_error_get_type())
 
 GType cogl_attribute_type_get_type (void) G_GNUC_CONST;
 #define COGL_TYPE_ATTRIBUTE_TYPE (cogl_attribute_type_get_type())
@@ -94,7 +94,7 @@ GType cogl_read_pixels_flags_get_type (void) G_GNUC_CONST;
 
 G_END_DECLS
 
-#endif /* !__CLUTTER_ENUM_TYPES_H__ */
+#endif /* __COGL_ENUM_TYPES_H__ */
 
 /* Generated data ends here */
 
